require 'logger'

require 'ruby_expect'
require 'active_support/all'

require 'serial/devices'

module SerialKiller
  extend self

  def connect(device: nil, host: nil, port: nil, offset: nil, timeout: nil, retries: nil, verbose: nil, keyfile: nil, username: '', password: '')
    options = { offset: offset, keyfile: keyfile, verbose: verbose, timeout: timeout, retries: retries }
    options[:username] = username unless username.empty?
    options[:password] = password unless password.empty?

    case device
    when 'sentry'
      sentry_connect(host, port, **options)
    else
      raise "#{device} is not supported"
    end
  end

  private

  def connect_device(host, port, offset: nil, keyfile: nil, verbose: nil, timeout: nil, retries: nil)
    logger = Logger.new(STDOUT)
    logger.level = Logger::DEBUG
    exp = RubyExpect::Expect.spawn("/usr/bin/ssh root@#{host} -i #{keyfile} -p #{offset + port}", logger: verbose ? logger : nil)
    exp.timeout = timeout

    attempts = 0
    exp.procedure do
      exp.send ''
      while attempts < retries
        sleep(1)
        yield exp
        sleep(5)
        attempts += 1
      end
    end
  end
end
