require 'thor'
require 'serial'

class SerialKiller::CLI < Thor
  desc 'connect', 'Connect to a device'
  method_option :device, type: :string, required: true, banner: 'DEVICE', desc: 'Type of device to connect to', enum: ['sentry'], aliases: '-d'
  method_option :host, type: :string, required: true, banner: 'HOST', desc: 'Serial console server host to connect to', aliases: '-h'
  method_option :port, type: :numeric, required: true, banner: 'PORT', desc: 'Serial console server port to connect to', aliases: '-p'
  method_option :username, type: :string, default: '', banner: 'USERNAME', desc: 'Username for login', aliases: '-U'
  method_option :password, type: :string, default: '', banner: 'PASSWORD', desc: 'Password for login', aliases: '-P'
  method_option :offset, type: :numeric, default: 3000, banner: 'OFFSET', desc: 'Port offset on serial console server', aliases: '-o'
  method_option :keyfile, type: :string, default: '/etc/conserver/.ssh/id_rsa', banner: 'KEYFILE', desc: 'Path to ssh keyfile', aliases: '-k'
  method_option :timeout, type: :numeric, default: 30, banner: 'TIMEOUT', desc: 'Time to wait before giving up', aliases: '-t'
  method_option :retries, type: :numeric, default: 5, banner: 'RETRIES', desc: 'Number of times to attempt to connect', aliases: '-r'
  method_option :verbose, type: :boolean, default: false, desc: 'Run with verbose debug output', aliases: '-v'
  def connect
    opts = options.deep_symbolize_keys
    SerialKiller.connect(**opts)
  end
end
